==> vuepress-plugin-pad-markdown-1.1.1.tgz: package/index.js <==
var hljs = require('highlight.js');
const path = require('path');
function copy_plugin(md) {
  function renderCodeWithCopyButton(tokens, idx, options, env, self) {
    // 添加语法高亮
    let highlightedContent = tokens[idx].content;
    const lang = tokens[idx].info;
    if (lang && hljs.getLanguage(lang)) {
      try {
        highlightedContent = hljs.highlight(tokens[idx].content, { language: lang }).value;
      } catch (__) { }
    }
    const content = tokens[idx].content.replace(/"/g, '&quot;');
    // 在渲染结果中添加一个复制按钮
    let result = `<div style="position: relative" class="mycodeblock"><pre><code>${highlightedContent}</code></pre><button class="code-copy-button" data-clipboard-text="${content}">  <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" width="16" height="16"><path stroke-linecap="round" stroke-linejoin="round" d="M15.666 3.888A2.25 2.25 0 0013.5 2.25h-3c-1.03 0-1.9.693-2.166 1.638m7.332 0c.055.194.084.4.084.612v0a.75.75 0 01-.75.75H9a.75.75 0 01-.75-.75v0c0-.212.03-.418.084-.612m7.332 0c.646.049 1.288.11 1.927.184 1.1.128 1.907 1.077 1.907 2.185V19.5a2.25 2.25 0 01-2.25 2.25H6.75A2.25 2.25 0 014.5 19.5V6.257c0-1.108.806-2.057 1.907-2.185a48.208 48.208 0 011.927-.184" /></svg></button></div>
`;
    return result;
  }
  // 覆盖 code_block 和 fence 规则，以便在渲染代码块时添加复制按钮
  md.renderer.rules.code_block = renderCodeWithCopyButton;
  md.renderer.rules.fence = renderCodeWithCopyButton;
}
module.exports = {
  enhanceAppFiles: path.resolve(__dirname, './enhanceApp.js'),
  extendMarkdown: md => {
    md.set({ breaks: true });
    md.use(require('markdown-it-katex'));
    md.use(require('markdown-it-footnote'));
    md.use(copy_plugin);
  }
};

==> vuepress-plugin-pad-markdown-1.1.5.tgz: package/index.js <==
var hljs = require('highlight.js');
const path = require('path');
function copy_plugin(md) {
  function renderCodeWithCopyButton(tokens, idx, options, env, self) {
    let highlightedContent = tokens[idx].content;
    const lang = tokens[idx].info;
    if (lang && hljs.getLanguage(lang)) {
      try {
        highlightedContent = hljs.highlight(tokens[idx].content, { language: lang }).value;
      } catch (__) { }
    }
    const content = tokens[idx].content.replace(/"/g, '&quot;');
    let result = `<div style="position: relative" class="mycodeblock"><pre><code>${highlightedContent}</code></pre><button class="code-copy-button" data-clipboard-text="${content}">  <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" width="16" height="16"><path stroke-linecap="round" stroke-linejoin="round" d="M15.666 3.888A2.25 2.25 0 0013.5 2.25h-3c-1.03 0-1.9.693-2.166 1.638m7.332 0c.055.194.084.4.084.612v0a.75.75 0 01-.75.75H9a.75.75 0 01-.75-.75v0c0-.212.03-.418.084-.612m7.332 0c.646.049 1.288.11 1.927.184 1.1.128 1.907 1.077 1.907 2.185V19.5a2.25 2.25 0 01-2.25 2.25H6.75A2.25 2.25 0 014.5 19.5V6.257c0-1.108.806-2.057 1.907-2.185a48.208 48.208 0 011.927-.184" /></svg></button></div>
`;
    return result;
  }
  // 覆盖 code_block 和 fence 规则，以便在渲染代码块时添加复制按钮
  md.renderer.rules.code_block = renderCodeWithCopyButton;
  md.renderer.rules.fence = renderCodeWithCopyButton;
}

module.exports = (options, ctx) => {
  return {
    name: "vuepress-plugin-pad-markdown",
    enhanceAppFiles: path.resolve(__dirname, './enhanceApp.js'),
    extendMarkdown: md => {
      if (options.break || options.useAllPlugins){
        md.set({ breaks: true });
      }
      if (options.katex || options.useAllPlugins) md.use(require('markdown-it-katex'));
      if (options.footnote || options.useAllPlugins) md.use(require('markdown-it-footnote'));
      if (options.mark || options.useAllPlugins) md.use(require("markdown-it-mark"))
      if (options.copy || options.useAllPlugins) md.use(copy_plugin);
    }
  };
};
